import React from 'react';
declare type GridRowGutterType = {
    mobile?: string | number | object;
    tablet?: string | number | object;
    desktop?: string | number | object;
};
export declare type GridRowProps = {
    /**
     * Уникальный идентификатор блока
     */
    id?: string;
    /**
     * Дополнительный класс
     */
    className?: string;
    /**
     * Горизонтальный отступ между колонками.
     * Возможные значения: `8n` px (n - натуральное число) из диапазона `[0, 8, 16, 24]`
     * или `{ mobile: [0..24], tablet: [0..24], desktop: [0..24] }`
     * или `{ mobile: { s: [0..24], m: [0..24], l: [0..24] },
     * tablet: { s: [0..24], m: [0..24] },
     * desktop: { s: [0..24], m: [0..24], l: [0..24], xl: [0..24] } }`.
     */
    gutter?: string | number | GridRowGutterType;
    /**
     * Управление выравниванием колонок по вертикальной оси
     */
    align?: 'top' | 'middle' | 'bottom';
    /**
     * Управление выравниванием колонок по горизонтальной оси
     */
    justify?: 'left' | 'center' | 'right' | 'around' | 'between';
    /**
     * Html тег компонента.
     * Из-за <a href="https://github.com/philipwalton/flexbugs#flexbug-9" target="_blank">ограничений и багов</a>,
     * существующих во флексбоксах, невозможно использовать
     * некоторые элементы HTML как flex-контейнеры</a>.
     */
    tag?: keyof JSX.IntrinsicElements;
    /**
     * Дочерние элементы `GridRow`
     */
    children?: React.ReactNode;
    /**
     * Идентификатор для систем автоматизированного тестирования
     */
    'data-test-id'?: string;
};
/**
 * Строка используется для создания сетки.
 * Сетка имеет резиновую систему разметки, которая масштабируется до 12 столбцов.
 */
export declare class GridRow extends React.PureComponent<GridRowProps> {
    protected cn: (this: void | {
        props?: Record<string, unknown>;
    }, elementNameOrMods?: string | {
        [key: string]: string | number | boolean;
    }, mods?: {
        [key: string]: string | number | boolean;
    }) => string;
    static defaultProps: Partial<GridRowProps>;
    /**
     * Класс колонки
     */
    private classCol;
    render(): JSX.Element;
    /**
     * Добавляет модификаторы горизонтальных отступов в дочерний элемент.
     *
     * @param gutters Модификаторы горизонтальных отступов
     * @param children Дочерние элементы компонента.
     */
    private injectGutterClassNamesToChildren;
}
export default GridRow;
