"use strict";
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var easings_1 = __importDefault(require("./easings"));
var vars_1 = require("../vars");
/**
* Скроллит по элементу или странице.
* В настоящее время доступно перемещение только по оси Y.
* TODO: Make a move on the x axis
*/
function scrollTo(_a) {
    var targetY = _a.targetY, container = _a.container, _b = _a.duration, duration = _b === void 0 ? 0 : _b, _c = _a.easing, easing = _c === void 0 ? vars_1.SCROLL_TO_EASING : _c;
    var scrollY = container ? container.scrollTop : window.pageYOffset;
    var startTime = window.performance.now();
    if (duration < 0) {
        throw new Error('Incorrect duration in options');
    }
    if (!easings_1.default[easing]) {
        throw new Error('Incorrect easing in options');
    }
    var easingFunc = easings_1.default[easing];
    return new Promise(function (resolve) {
        function scrollToTarget(y) {
            if (container) {
                // eslint-disable-next-line no-param-reassign
                container.scrollTop = y;
            }
            else {
                window.scrollTo(0, y);
            }
        }
        function loop(timestamp) {
            var currentTime = Math.abs(timestamp - startTime);
            var t = currentTime / duration;
            var val = easingFunc(t);
            var currentTargetY = scrollY + ((targetY - scrollY) * val);
            if (t < 1) {
                window.requestAnimationFrame(loop);
                scrollToTarget(currentTargetY);
            }
            else {
                scrollToTarget(targetY);
                resolve();
            }
        }
        if (duration === 0) {
            scrollToTarget(targetY);
            resolve();
        }
        else {
            loop(window.performance.now());
        }
    });
}
exports.default = scrollTo;

//# sourceMappingURL=scroll-to.js.map
